@@ -181,9 +181,13 @@ def upload_file(
 
     bucket_name = upload_info.bucket
     prefix = upload_info.prefix_to_save
+
     object_key = os.path.join(
-        upload_info.prefix_to_save, generate_timestamped_string(1), path_in_dataset
+        upload_info.prefix_to_save, generate_timestamped_string(1)
     )
+    if path_in_dataset != "":
+        object_key = os.path.join(object_key, path_in_dataset)
+    # print(f"upload object key {object_key}")
     try:
         if isinstance(path_or_fileobj, (str, Path)):
             with open(path_or_fileobj, "rb") as file:
@@ -199,12 +203,38 @@ def upload_file(
             if _get_file_in_dataset(prefix, file.key) != path_in_dataset:
                 new_dataset_files.append(file)
             elif not overwrite:
-                print("file exists, skip uploading")
+                # print("file exists, skip uploading")
                 return
         new_dataset_files.append(DatasetFile("", object_key, 0))
         _update_dataset(id, new_dataset_files, token)
 
 
+def upload_folder(
+    folder_path: str | Path,
+    path_in_dataset: str,
+    id: str | Dataset,
+    overwrite: bool = False,
+    token: Optional[str] = None,
+):
+    if token is None:
+        token = os.getenv("MW_TOKEN")
+        if not token:
+            raise ValueError(
+                "No token provided and 'MW_TOKEN' environment variable is not set."
+            )
+    if isinstance(id, Dataset):
+        id = id._id
+    # Walk through the directory
+    for root, _dirs, files in os.walk(folder_path):
+        for file in files:
+            file_path = os.path.join(root, file)
+            rel_path = os.path.relpath(os.path.join(root, file), folder_path)
+            # print(f"root {root} rel_path {rel_path} upload file {file_path} path in {os.path.join(path_in_dataset,rel_path)} id {id}")
+            upload_file(
+                file_path, os.path.join(path_in_dataset, rel_path), id, overwrite, token
+            )
+
+
 def _get_file_in_dataset(prefix: str, object_key: str) -> str:
     """
     Extracts the file path from the object key in a dataset.
@@ -398,7 +428,7 @@ def create_dataset(
     folder_name: Optional[str] = None,
     token: Optional[str] = None,
     enable_download: bool = True,
-) -> Dataset:
+) -> Optional[Dataset]:
     """Creates a empty dataset
 
     Args:
@@ -424,6 +454,8 @@ def create_dataset(
     if short_description is None:
         short_description = title
     upload_info = _get_update_token(token)
+    if upload_info is None:
+        raise ValueError("Failed to get upload token.")
     session = boto3.Session(
         aws_access_key_id=upload_info.ak,
         aws_secret_access_key=upload_info.sk,
@@ -455,6 +487,7 @@ def create_dataset(
         url,
         json=data,
         headers=headers,
+        timeout=10,
     )
 
     if response.status_code == 200:
@@ -470,3 +503,4 @@ def create_dataset(
         )
     else:
         response.raise_for_status()
+        return None
